/*****************************************************************
* Unipro UGENE - Integrated Bioinformatics Suite
* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
* All Rights Reserved
* 
*     This source code is distributed under the terms of the
*     GNU General Public License. See the files COPYING and LICENSE
*     for details.
*****************************************************************/

#ifndef _U2_ORF_MARKER_PLUGIN_H_
#define _U2_ORF_MARKER_PLUGIN_H_

#include <U2Core/PluginModel.h>
#include <U2Gui/ObjectViewModel.h>

namespace U2 {

class XMLTestFactory;

class ORFMarkerPlugin : public Plugin {
    Q_OBJECT
public:
    ORFMarkerPlugin();
    ~ORFMarkerPlugin();

private:
    GObjectViewWindowContext* viewCtx;
};

class ORFViewContext: public GObjectViewWindowContext {
    Q_OBJECT
public:
    ORFViewContext(QObject* p);

protected slots:
        void sl_showDialog();

protected:
    virtual void initViewContext(GObjectView* view);
};

class ORFMarkerTests {
public:
    static QList<XMLTestFactory*> createTestFactories();
};


} //namespace

#endif

